## Product details

Superhero Avengers wall stickers it is the perfect decoration for any animation themed party and will surely excite fans and lovers of all ages.The stickers is the perfect complement to the game room, bedroom, hall, study, children's room, etc. Its durable design and vibrant colors make it your favorite game time!
Premium Wall Sticker: Material-Thick PVC material, non-toxic, removable and durable for long time use. Waterproof material. Don't worry damage.
Packaging and size: Our Superhero Avengers stickers come in rolls, and a wall pack of stickers is about 15.7 "x23.6", a size that fits most of your decorating scenes.
Design Philosophy: Our wall stickers are carefully designed and printed. Unique wall stickers add color and vibrancy to a child's room, and they can also be the perfect holiday or birthday gift for your friends and family - all Avengers fans will be captivated by Captain America's superhero action!
info:
We aim to show you accurate product information. Manufacturers, suppliers and others provide what you see here, and we have not verified it.  See our disclaimer
## Specifications

Character
Spider-Man
Size
16" x 24"
Material
PVC
Age group
Teen
More details
## Warranty

Warranty information
Please be aware that the warranty terms on items offered for sale by third party Marketplace sellers may differ from those displayed in this section (if any). To confirm warranty terms on an item offered for sale by a third party Marketplace seller, please use the 'Contact seller' feature on the third party Marketplace seller's information page and request the item's warranty terms prior to purchase.
